package com.sun.xml.internal.ws.policy;

import com.sun.xml.internal.ws.policy.subject.PolicyMapKeyConverter;
import java.util.LinkedList;
import com.sun.xml.internal.ws.policy.subject.WsdlBindingSubject;
import java.util.HashMap;
import javax.xml.namespace.QName;
import java.util.Collection;
import java.util.Iterator;
import com.sun.xml.internal.ws.policy.privateutil.LocalizationMessages;
import com.sun.xml.internal.ws.policy.privateutil.PolicyLogger;

public class PolicyMapUtil
{
    private static final PolicyLogger LOGGER;
    private static final PolicyMerger MERGER;
    
    private PolicyMapUtil() {
    }
    
    public static void rejectAlternatives(PolicyMap map) throws PolicyException {
        for (Policy policy : map) {
            if (policy.getNumberOfAssertionSets() > 1) {
                throw (PolicyException)PolicyMapUtil.LOGGER.logSevereException(new PolicyException(LocalizationMessages.WSP_0035_RECONFIGURE_ALTERNATIVES(policy.getIdOrName())));
            }
            continue;
        }
    }
    
    public static void insertPolicies(PolicyMap policyMap, Collection<PolicySubject> policySubjects, QName serviceName, QName portName) throws PolicyException {
        PolicyMapUtil.LOGGER.entering(new Object[] { policyMap, policySubjects, serviceName, portName });
        HashMap<WsdlBindingSubject, Collection<Policy>> subjectToPolicies = new HashMap();
        for (PolicySubject subject : policySubjects) {
            Object actualSubject = subject.getSubject();
            if ((actualSubject instanceof WsdlBindingSubject)) {
                WsdlBindingSubject wsdlSubject = (WsdlBindingSubject)actualSubject;
                Collection<Policy> subjectPolicies = new LinkedList();
                subjectPolicies.add(subject.getEffectivePolicy(PolicyMapUtil.MERGER));
                Collection<Policy> existingPolicies = (Collection<Policy>)subjectToPolicies.put(wsdlSubject, subjectPolicies);
                if (existingPolicies != null) {
                    subjectPolicies.addAll(existingPolicies);
                }
                else {
                    continue;
                }
            }
            else {
                continue;
            }
        }
        PolicyMapKeyConverter converter = new PolicyMapKeyConverter(serviceName, portName);
        for (WsdlBindingSubject wsdlSubject2 : subjectToPolicies.keySet()) {
            PolicySubject newSubject = new PolicySubject(wsdlSubject2, (Collection)subjectToPolicies.get(wsdlSubject2));
            PolicyMapKey mapKey = converter.getPolicyMapKey(wsdlSubject2);
            if (wsdlSubject2.isBindingSubject()) {
                policyMap.putSubject(PolicyMap.ScopeType.ENDPOINT, mapKey, newSubject);
            }
            else if (wsdlSubject2.isBindingOperationSubject()) {
                policyMap.putSubject(PolicyMap.ScopeType.OPERATION, mapKey, newSubject);
            }
            else if (wsdlSubject2.isBindingMessageSubject()) {
                switch (wsdlSubject2.getMessageType()) {
                    case INPUT: {
                        policyMap.putSubject(PolicyMap.ScopeType.INPUT_MESSAGE, mapKey, newSubject);
                        continue;
                    }
                    case OUTPUT: {
                        policyMap.putSubject(PolicyMap.ScopeType.OUTPUT_MESSAGE, mapKey, newSubject);
                        continue;
                    }
                    case FAULT: {
                        policyMap.putSubject(PolicyMap.ScopeType.FAULT_MESSAGE, mapKey, newSubject);
                        continue;
                    }
                }
            }
            else {
                continue;
            }
        }
        PolicyMapUtil.LOGGER.exiting();
    }
    
    static {
        LOGGER = PolicyLogger.getLogger(PolicyMapUtil.class);
        MERGER = PolicyMerger.getMerger();
    }
}
